pygraphviz: Python interface to Graphviz
========================================

Description
-----------

Python interface to Graphviz

License
-------

BSD

Upstream Contact
----------------

https://pypi.org/project/pygraphviz/

